#include <inttypes.h>
#include <avr/io.h>
#include <util/delay.h>
//connect one end of the sensor to GND, the other one to ADC0,
//and connect ADC0 with VCC using 38k resistor.


#include <stdio.h>

#include <uart2.h>
#include <a2d.h>

static int uart1_putchar(char c, FILE *stream);
static FILE mystdout = FDEV_SETUP_STREAM(uart1_putchar, NULL, _FDEV_SETUP_WRITE);

// outputs one character to UART1
static int uart1_putchar(char c, FILE *stream)
{
 //we live in Windows world now 
 if (c == '\n') uart1_putchar('\r', stream);

 //use UCSRnA, UDREn, UDRn,  for n=0,1,2 for different UARTs
 loop_until_bit_is_set(UCSR1A, UDRE1);
 UDR1 = c;

 return 0;
}

//this function sleeps s seconds (if F_CPU is set to frequency of processor)
void dsleep(uint8_t s)
{
  uint8_t i;
  while (s--) for (i = 0; i < 10; i++) _delay_ms(10);
}

int main(void)
{
  uint8_t i;
  uint8_t val;
  
  DDRE = 0xFF;
  PORTE = PINE | 16;
  
  //initialize UART1 as 2400/odd parity (that's how our BlueSmirf is configured)
  uart1Init();
  uartSetBaudRate(1, 2400);
  UCSR1C |= 48;

  //setup character output function for stdout
  stdout = &mystdout;
    
  a2dInit();
  a2dSetPrescaler(ADC_PRESCALE_DIV128);
  
  
  DDRA = 0x00;
  PORTA = 0x00;
  
  for (i = 0; i < 100; i++)
  {
    dsleep(2);
	val = a2dConvert8bit(0);
  	PORTE = PINE ^ 32;
	printf("%d: %d\n", i, val);
  }
  
  a2dOff();
  PORTE = 0x0;
  
  return 0;
  
} //end main function


